package com.srs.comprehensive.mapper;

import java.util.List;

import com.srs.comprehensive.domain.SrsZxjTime;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 助学金审核时间Mapper接口
 *
 * @author srs
 * @date 2024-06-05
 */
public interface SrsZxjTimeMapper extends BaseMapper<SrsZxjTime> {
    /**
     * 查询助学金审核时间
     *
     * @param id 助学金审核时间主键
     * @return 助学金审核时间
     */
    public SrsZxjTime selectSrsZxjTimeById(Long id);

    /**
     * 查询助学金审核时间列表
     *
     * @param srsZxjTime 助学金审核时间
     * @return 助学金审核时间集合
     */
    List<SrsZxjTime> selectSrsZxjTimeList(SrsZxjTime srsZxjTime);

    /**
     * 新增助学金审核时间
     *
     * @param srsZxjTime 助学金审核时间
     * @return 结果
     */
    int insertSrsZxjTime(SrsZxjTime srsZxjTime);

    /**
     * 修改助学金审核时间
     *
     * @param srsZxjTime 助学金审核时间
     * @return 结果
     */
    int updateSrsZxjTime(SrsZxjTime srsZxjTime);

    /**
     * 删除助学金审核时间
     *
     * @param id 助学金审核时间主键
     * @return 结果
     */
    int deleteSrsZxjTimeById(Long id);

    /**
     * 批量删除助学金审核时间
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSrsZxjTimeByIds(Long[] ids);
}
